@@ -11,7 +11,12 @@ from django.contrib.auth.models import User
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _, ugettext
-from django.utils import timezone
+
+try:
+    from django.utils import timezone
+except ImportError:
+    from datetime import datetime as timezone
+
 from helpdesk.settings import HAS_TAG_SUPPORT
 
 if HAS_TAG_SUPPORT:
@@ -384,7 +389,9 @@ class Ticket(models.Model):
         """
         held_msg = ''
         if self.on_hold: held_msg = _(' - On Hold')
-        return u'%s%s' % (self.get_status_display(), held_msg)
+        dep_msg = ''
+        if self.can_be_resolved == False: dep_msg = _(' - Open dependencies')
+        return u'%s%s%s' % (self.get_status_display(), held_msg, dep_msg)
     get_status = property(_get_status)
 
     def _get_ticket_url(self):
